@@ -75,7 +75,9 @@ void benchmark_rx_rate(uhd::usrp::multi_usrp::sptr usrp,
     const start_time_type& start_time,
     std::atomic<bool>& burst_timer_elapsed,
     bool elevate_priority,
-    double rx_delay)
+    double adjusted_rx_delay,
+    double user_rx_delay,
+    bool rx_stream_now)
 {
     if (elevate_priority) {
         uhd::set_thread_priority_safe();
@@ -105,20 +107,15 @@ void benchmark_rx_rate(uhd::usrp::multi_usrp::sptr usrp,
     cmd.num_samps = spb;
     if (random_nsamps) {
         cmd.stream_mode = uhd::stream_cmd_t::STREAM_MODE_NUM_SAMPS_AND_DONE;
-        cmd.num_samps = (rand() % spb) + 1;
+        cmd.num_samps   = (rand() % spb) + 1;
     }
-    // Multiple channels must be time aligned, so a default delay is set if
-    // not specified.
-    cmd.time_spec  = usrp->get_time_now() + uhd::time_spec_t(
-                     rx_delay == 0.0 ? 0.05 : rx_delay);
-    // Streaming can only start immediately if there is a single channel
-    // and the user has not requested a delay.
-    cmd.stream_now = (rx_delay == 0.0 and buffs.size() == 1);
+
+    cmd.time_spec  = usrp->get_time_now() + uhd::time_spec_t(adjusted_rx_delay);
+    cmd.stream_now = rx_stream_now;
     rx_stream->issue_stream_cmd(cmd);
 
-    const float burst_pkt_time =
-        std::max<float>(0.100f, (2 * spb / rate));
-    float recv_timeout = burst_pkt_time + (rx_delay == 0.0 ? 0.05 : rx_delay);
+    const float burst_pkt_time = std::max<float>(0.100f, (2 * spb / rate));
+    float recv_timeout         = burst_pkt_time + (adjusted_rx_delay);
 
     bool stop_called = false;
     while (true) {
@@ -127,7 +124,7 @@ void benchmark_rx_rate(uhd::usrp::multi_usrp::sptr usrp,
             stop_called = true;
         }
         if (random_nsamps) {
-            cmd.time_spec  = usrp->get_time_now() + uhd::time_spec_t(rx_delay);
+            cmd.time_spec = usrp->get_time_now() + uhd::time_spec_t(user_rx_delay);
             cmd.num_samps = (rand() % spb) + 1;
             rx_stream->issue_stream_cmd(cmd);
         }
@@ -233,20 +230,14 @@ void benchmark_tx_rate(uhd::usrp::multi_usrp::sptr usrp,
                      % time_stamp % (tx_rate / 1e6) % num_channels;
 
     // setup variables and allocate buffer
-    std::vector<char> buff(
-        spb * uhd::convert::get_bytes_per_item(tx_cpu));
+    std::vector<char> buff(spb * uhd::convert::get_bytes_per_item(tx_cpu));
     std::vector<const void*> buffs;
     for (size_t ch = 0; ch < tx_stream->get_num_channels(); ch++)
         buffs.push_back(&buff.front()); // same buffer for each channel
     // Create the metadata, and populate the time spec at the latest possible moment
     uhd::tx_metadata_t md;
-    // A time_spec is needed to time align multiple channels or if the user specifies
-    // a delay.
-    md.has_time_spec = (tx_delay != 0.0 or num_channels > 1);
-    // Multiple channels must be time aligned, so a default delay is set if
-    // not specified.  It is only used if has_time_spec is true.
-    md.time_spec     = usrp->get_time_now() + uhd::time_spec_t(
-                       tx_delay == 0.0 ? 0.25 : tx_delay);
+    md.has_time_spec = (tx_delay != 0.0);
+    md.time_spec     = usrp->get_time_now() + uhd::time_spec_t(tx_delay);
 
     // Calculate timeout time
     // The timeout time cannot be reduced after the first packet as is done for
@@ -254,9 +245,8 @@ void benchmark_tx_rate(uhd::usrp::multi_usrp::sptr usrp,
     // are full and that is dependent on several factors such as the device,
     // FPGA configuration, and device arguments.  The extra 100ms is to account
     // for overhead of the send() call (enough).
-    const double burst_pkt_time =
-        std::max<double>(0.1, (2.0 * spb / tx_rate));
-    double timeout = burst_pkt_time + (tx_delay == 0.0 ? 0.25 : tx_delay);
+    const double burst_pkt_time = std::max<double>(0.1, (2.0 * spb / tx_rate));
+    double timeout              = burst_pkt_time + tx_delay;
 
     if (random_nsamps) {
         std::srand((unsigned int)time(NULL));
@@ -349,7 +339,8 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
     std::atomic<bool> burst_timer_elapsed(false);
     size_t overrun_threshold, underrun_threshold, drop_threshold, seq_threshold;
     size_t rx_spp, tx_spp, rx_spb, tx_spb;
-    double tx_delay, rx_delay;
+    double tx_delay, rx_delay, adjusted_tx_delay, adjusted_rx_delay;
+    bool rx_stream_now = false;
     std::string priority;
     bool elevate_priority = false;
 
@@ -388,7 +379,8 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
          "Number of dropped packets (D) which will declare the benchmark a failure.")
         ("seq-threshold", po::value<size_t>(&seq_threshold),
          "Number of dropped packets (D) which will declare the benchmark a failure.")
-        // NOTE: TX delay defaults to 0.25 seconds to allow the buffer on the device to fill completely
+        // NOTE: tx_delay defaults to 0.25 while rx_delay defaults to 0.05 when left unspecified
+        // in multi-channel and multi-streamer configurations.
         ("tx_delay", po::value<double>(&tx_delay)->default_value(0.0), "delay before starting TX in seconds")
         ("rx_delay", po::value<double>(&rx_delay)->default_value(0.0), "delay before starting RX in seconds")
         ("priority", po::value<std::string>(&priority)->default_value("normal"), "thread priority (normal, high)")
@@ -421,6 +413,9 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
         random_nsamps = true;
     }
 
+    adjusted_tx_delay = tx_delay;
+    adjusted_rx_delay = rx_delay;
+
     // create a usrp device
     std::cout << std::endl;
     uhd::device_addrs_t device_addrs = uhd::device::find(args, uhd::device::USRP);
@@ -551,6 +546,20 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
     // spawn the receive test thread
     if (vm.count("rx_rate")) {
         usrp->set_rx_rate(rx_rate);
+        // Set an appropriate rx_delay value (if needed) to be used as the time_spec for
+        // streaming.
+        // A time_spec is needed to time align multiple channels or if the user specifies
+        // a delay. Also delay start in case we are using multiple streamers to stream
+        // multi channel data to avoid management transaction contention between threads
+        // during setup.
+        if ((rx_delay == 0.0 || vm.count("multi_streamer"))
+            && rx_channel_nums.size() > 1) {
+            adjusted_rx_delay = std::max(rx_delay, 0.05);
+        }
+        if (rx_delay == 0.0
+            && (vm.count("multi_streamer") || rx_channel_nums.size() == 1)) {
+            rx_stream_now = true;
+        }
 
         size_t spb = 0;
         if (vm.count("rx_spp")) {
@@ -564,7 +573,7 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
         if (vm.count("multi_streamer")) {
             for (size_t count = 0; count < rx_channel_nums.size(); count++) {
                 std::vector<size_t> this_streamer_channels{rx_channel_nums[count]};
-                 // create a receive streamer
+                // create a receive streamer
                 uhd::stream_args_t stream_args(rx_cpu, rx_otw);
                 stream_args.channels             = this_streamer_channels;
                 stream_args.args                 = uhd::device_addr_t(rx_stream_args);
@@ -578,12 +587,13 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
                         start_time,
                         burst_timer_elapsed,
                         elevate_priority,
-                        rx_delay);
+                        adjusted_rx_delay,
+                        rx_delay,
+                        rx_stream_now);
                 });
                 uhd::set_thread_name(rx_thread, "bmark_rx_strm" + std::to_string(count));
             }
-        }
-        else {
+        } else {
             // create a receive streamer
             uhd::stream_args_t stream_args(rx_cpu, rx_otw);
             stream_args.channels             = rx_channel_nums;
@@ -598,7 +608,9 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
                     start_time,
                     burst_timer_elapsed,
                     elevate_priority,
-                    rx_delay);
+                    adjusted_rx_delay,
+                    rx_delay,
+                    rx_stream_now);
             });
             uhd::set_thread_name(rx_thread, "bmark_rx_stream");
         }
@@ -607,42 +619,55 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
     // spawn the transmit test thread
     if (vm.count("tx_rate")) {
         usrp->set_tx_rate(tx_rate);
+        // Set an appropriate tx_delay value (if needed) to be used as the time_spec for
+        // streaming.
+        // A time_spec is needed to time align multiple channels or if the user specifies
+        // a delay. Also delay start in case we are using multiple streamers to stream
+        // multi channel data to avoid management transaction contention between threads
+        // during setup.
+        if ((tx_delay == 0.0 || vm.count("multi_streamer"))
+            && tx_channel_nums.size() > 1) {
+            adjusted_tx_delay = std::max(tx_delay, 0.25);
+        }
 
         if (vm.count("multi_streamer")) {
-                for (size_t count = 0; count < tx_channel_nums.size(); count++) {
-                    std::vector<size_t> this_streamer_channels{tx_channel_nums[count]};
+            for (size_t count = 0; count < tx_channel_nums.size(); count++) {
+                std::vector<size_t> this_streamer_channels{tx_channel_nums[count]};
 
-            // create a transmit streamer
-            uhd::stream_args_t stream_args(tx_cpu, tx_otw);
-            stream_args.channels             = this_streamer_channels;
-            stream_args.args                 = uhd::device_addr_t(tx_stream_args);
-            uhd::tx_streamer::sptr tx_stream = usrp->get_tx_stream(stream_args);
-            const size_t max_spp             = tx_stream->get_max_num_samps();
-            size_t spp                       = max_spp;
-            if (vm.count("tx_spp")) {
-                spp = std::min(spp, tx_spp);
-            }
-            size_t spb                       = spp;
-            if (vm.count("tx_spb")) {
-                spb = tx_spb;
-            }
-            std::cout << boost::format("Setting TX spb to %u\n") % spb;
-            auto tx_thread = thread_group.create_thread([=, &burst_timer_elapsed]() {
-                benchmark_tx_rate(usrp,
-                tx_cpu,
-                tx_stream,
-                burst_timer_elapsed,
-                start_time,
-                spb,
-                elevate_priority,
-                tx_delay,
-                random_nsamps);
-            });
-            uhd::set_thread_name(tx_thread, "bmark_tx_strm" + std::to_string(count));
-            auto tx_async_thread = thread_group.create_thread([=, &burst_timer_elapsed]() {
-                benchmark_tx_rate_async_helper(tx_stream, start_time, burst_timer_elapsed);
-            });
-            uhd::set_thread_name(tx_async_thread, "bmark_tx_hlpr" + std::to_string(count));
+                // create a transmit streamer
+                uhd::stream_args_t stream_args(tx_cpu, tx_otw);
+                stream_args.channels             = this_streamer_channels;
+                stream_args.args                 = uhd::device_addr_t(tx_stream_args);
+                uhd::tx_streamer::sptr tx_stream = usrp->get_tx_stream(stream_args);
+                const size_t max_spp             = tx_stream->get_max_num_samps();
+                size_t spp                       = max_spp;
+                if (vm.count("tx_spp")) {
+                    spp = std::min(spp, tx_spp);
+                }
+                size_t spb = spp;
+                if (vm.count("tx_spb")) {
+                    spb = tx_spb;
+                }
+                std::cout << boost::format("Setting TX spb to %u\n") % spb;
+                auto tx_thread = thread_group.create_thread([=, &burst_timer_elapsed]() {
+                    benchmark_tx_rate(usrp,
+                        tx_cpu,
+                        tx_stream,
+                        burst_timer_elapsed,
+                        start_time,
+                        spb,
+                        elevate_priority,
+                        adjusted_tx_delay,
+                        random_nsamps);
+                });
+                uhd::set_thread_name(tx_thread, "bmark_tx_strm" + std::to_string(count));
+                auto tx_async_thread =
+                    thread_group.create_thread([=, &burst_timer_elapsed]() {
+                        benchmark_tx_rate_async_helper(
+                            tx_stream, start_time, burst_timer_elapsed);
+                    });
+                uhd::set_thread_name(
+                    tx_async_thread, "bmark_tx_hlpr" + std::to_string(count));
             }
         } else {
             // create a transmit streamer
@@ -655,37 +680,42 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
             if (vm.count("tx_spp")) {
                 spp = std::min(spp, tx_spp);
             }
-            size_t spb                       = spp;
+            size_t spb = spp;
             if (vm.count("tx_spb")) {
                 spb = tx_spb;
             }
             std::cout << boost::format("Setting TX spp to %u\n") % spp;
             auto tx_thread = thread_group.create_thread([=, &burst_timer_elapsed]() {
                 benchmark_tx_rate(usrp,
-                tx_cpu,
-                tx_stream,
-                burst_timer_elapsed,
-                start_time,
-                spb,
-                elevate_priority,
-                tx_delay,
-                random_nsamps);
+                    tx_cpu,
+                    tx_stream,
+                    burst_timer_elapsed,
+                    start_time,
+                    spb,
+                    elevate_priority,
+                    adjusted_tx_delay,
+                    random_nsamps);
             });
             uhd::set_thread_name(tx_thread, "bmark_tx_stream");
-            auto tx_async_thread = thread_group.create_thread([=, &burst_timer_elapsed]() {
-                benchmark_tx_rate_async_helper(tx_stream, start_time, burst_timer_elapsed);
-            });
+            auto tx_async_thread =
+                thread_group.create_thread([=, &burst_timer_elapsed]() {
+                    benchmark_tx_rate_async_helper(
+                        tx_stream, start_time, burst_timer_elapsed);
+                });
             uhd::set_thread_name(tx_async_thread, "bmark_tx_helper");
         }
     }
 
-    // sleep for the required duration (add any initial delay)
+    // Sleep for the required duration (add any initial delay).
+    // If you are benchmarking Rx and Tx at the same time, Rx threads will run longer
+    // than specified duration if tx_delay > rx_delay because of the overly simplified
+    // logic below and vice versa.
     if (vm.count("rx_rate") and vm.count("tx_rate")) {
-        duration += std::max(rx_delay, tx_delay);
+        duration += std::max(adjusted_rx_delay, adjusted_tx_delay);
     } else if (vm.count("rx_rate")) {
-        duration += rx_delay;
+        duration += adjusted_rx_delay;
     } else {
-        duration += tx_delay;
+        duration += adjusted_tx_delay;
     }
     const int64_t secs  = int64_t(duration);
     const int64_t usecs = int64_t((duration - secs) * 1e6);
@@ -753,4 +783,4 @@ int UHD_SAFE_MAIN(int argc, char* argv[])
         return EXIT_FAILURE;
     }
     return EXIT_SUCCESS;
-}
+}
\ No newline at end of file
