@@ -7,7 +7,9 @@
 #pragma once
 
 #include <uhdlib/rfnoc/rf_control/dboard_iface.hpp>
+#include <complex>
 #include <memory>
+#include <string>
 
 namespace uhd { namespace usrp { namespace x400 {
 
@@ -20,7 +22,12 @@ struct adc_self_cal_params_t
 {
     double rx_freq;
     double tx_freq;
+    std::complex<int32_t> dac_iq_values;
+    uint32_t threshold_delay;
+    uint32_t threshold_under;
+    uint32_t threshold_over;
     std::string calibration_mode;
+    uint32_t calibration_time;
 };
 
 /*! Interface for daughterboards which support being plugged into a X400 motherboard.
@@ -41,6 +48,16 @@ public:
     //! that is suitable for ADC self calibration.
     //! Returns true, if a suitable gain was found, false otherwise.
     virtual bool select_adc_self_cal_gain(size_t chan) = 0;
+
+    //! Returns the RFdc converter rate, i.e., the rate at which the converters
+    //! are clocked. May be different from the actual sampling rate, if the RFdc
+    //! resamplers are enabled.
+    virtual double get_converter_rate() const = 0;
+
+    //! Returns the number of rx channels on the daughterboard
+    virtual size_t get_num_rx_channels() const = 0;
+    //! Returns the number of tx channels on the daughterboard
+    virtual size_t get_num_tx_channels() const = 0;
 };
 
 }}} // namespace uhd::usrp::x400
