@@ -578,6 +578,7 @@ public:
     void commit() override
     {
         _graph->commit();
+        UHD_LOG_TRACE(LOG_ID, "new graph committed" << std::endl << _graph->to_dot());
     }
 
     void release() override
@@ -585,6 +586,11 @@ public:
         _graph->release();
     }
 
+    std::string to_dot() override
+    {
+        return _graph->to_dot();
+    }
+
 private:
     /**************************************************************************
      * Device Setup
