@@ -19,7 +19,7 @@ BOOST_AUTO_TEST_CASE(test_isatty)
         std::cout << "stderr is not a TTY" << std::endl;
     }
     auto tmp_file =
-        std::unique_ptr<std::FILE, decltype(&std::fclose)>(std::tmpfile(), &std::fclose);
+        std::unique_ptr<std::FILE, int (*)(FILE*)>(std::tmpfile(), &std::fclose);
 #ifdef UHD_PLATFORM_WIN32
     BOOST_REQUIRE(!uhd::is_a_tty(_fileno(tmp_file.get())));
 #elif _POSIX_C_SOURCE >= _200112L
