@@ -103,118 +103,118 @@ RFDC_PLL_CONFIGS = {
 # Lists the LMK VCOs rates to be used per Master Clock Rate
 # Format: {MCR: LMK-VCO rate}
 MCR_LMK_VCO = {
-    125000000.0: 3000000000.0,
-    128000000.0: 3072000000.0,
-    133120000.0: 3194880000.0,
-    150000000.0: 3000000000.0,
-    153600000.0: 2457600000.0,
-    160000000.0: 3200000000.0,
-    163840000.0: 2949120000.0,
-    184320000.0: 2949120000.0,
-    199680000.0: 3194880000.0,
-    200000000.0: 3200000000.0,
-    204800000.0: 3072000000.0,
-    240000000.0: 3000000000.0,
-    245760000.0: 3194880000.0,
-    250000000.0: 3000000000.0,
-    256000000.0: 3200000000.0,
-    266240000.0: 3194880000.0,
-    300000000.0: 3000000000.0,
-    307200000.0: 2457600000.0,
-    320000000.0: 3200000000.0,
-    327680000.0: 2949120000.0,
-    360000000.0: 3000000000.0,
-    368640000.0: 2949120000.0,
-    375000000.0: 3000000000.0,
-    384000000.0: 3072000000.0,
-    399360000.0: 3194880000.0,
-    400000000.0: 3200000000.0,
-    409600000.0: 3072000000.0,
-    450000000.0: 3000000000.0,
-    460800000.0: 3072000000.0,
-    480000000.0: 3000000000.0,
-    491520000.0: 3194880000.0,
-    500000000.0: 3000000000.0,
-    512000000.0: 3072000000.0,
-    532480000.0: 3194880000.0,
-    552960000.0: 2949120000.0,
-    599040000.0: 3194880000.0,
-    600000000.0: 3000000000.0,
-    614400000.0: 2457600000.0,
-    625000000.0: 2500000000.0,
-    640000000.0: 3200000000.0,
-    655360000.0: 2949120000.0,
-    665600000.0: 3194880000.0,
-    720000000.0: 3000000000.0,
-    737280000.0: 2949120000.0,
-    750000000.0: 3000000000.0,
-    768000000.0: 3072000000.0,
-    798720000.0: 3194880000.0,
-    800000000.0: 3200000000.0,
-    819200000.0: 3072000000.0,
-    840000000.0: 3000000000.0,
-    860160000.0: 3194880000.0,
-    875000000.0: 3000000000.0,
-    896000000.0: 3200000000.0,
-    900000000.0: 3000000000.0,
-    921600000.0: 3072000000.0,
-    931840000.0: 3194880000.0,
-    960000000.0: 3000000000.0,
-    983040000.0: 3194880000.0,
-    998400000.0: 3194880000.0,
-    1000000000.0: 3000000000.0,
-    1024000000.0: 3200000000.0,
-    1050000000.0: 3000000000.0,
-    1064960000.0: 3194880000.0,
-    1075200000.0: 3072000000.0,
-    1080000000.0: 3000000000.0,
-    1105920000.0: 2949120000.0,
-    1120000000.0: 3200000000.0,
-    1125000000.0: 3000000000.0,
-    1146880000.0: 2949120000.0,
-    1152000000.0: 3072000000.0,
-    1198080000.0: 3194880000.0,
-    1200000000.0: 3200000000.0,
-    1228800000.0: 2457600000.0,
-    1280000000.0: 3200000000.0,
-    1290240000.0: 2949120000.0,
-    1310720000.0: 2949120000.0,
-    1331200000.0: 3194880000.0,
-    1350000000.0: 3000000000.0,
-    1382400000.0: 3072000000.0,
-    1397760000.0: 3194880000.0,
-    1400000000.0: 3200000000.0,
-    1433600000.0: 3072000000.0,
-    1440000000.0: 3000000000.0,
-    1474560000.0: 2949120000.0,
-    1500000000.0: 3000000000.0,
-    1536000000.0: 3072000000.0,
-    1600000000.0: 3200000000.0,
-    1625000000.0: 3000000000.0,
-    1638400000.0: 3072000000.0,
-    1650000000.0: 3000000000.0,
-    1658880000.0: 2949120000.0,
-    1664000000.0: 3200000000.0,
-    1680000000.0: 3000000000.0,
-    1689600000.0: 3072000000.0,
-    1720320000.0: 3194880000.0,
-    1730560000.0: 3194880000.0,
-    1750000000.0: 3000000000.0,
-    1760000000.0: 3200000000.0,
-    1792000000.0: 3200000000.0,
-    1797120000.0: 3194880000.0,
-    1800000000.0: 3000000000.0,
-    1802240000.0: 2949120000.0,
-    1843200000.0: 2949120000.0,
-    1863680000.0: 3194880000.0,
-    1875000000.0: 3000000000.0,
-    1920000000.0: 3000000000.0,
-    1950000000.0: 3000000000.0,
-    1966080000.0: 3194880000.0,
-    1996800000.0: 3194880000.0,
-    2000000000.0: 3000000000.0,
-    2027520000.0: 2949120000.0,
-    2048000000.0: 3200000000.0
+    125000000.0: [3000000000.0,],
+    128000000.0: [3072000000.0,],
+    133120000.0: [3194880000.0,],
+    150000000.0: [3000000000.0,],
+    153600000.0: [2457600000.0,],
+    160000000.0: [3200000000.0,],
+    163840000.0: [2949120000.0,2457600000.0],
+    184320000.0: [2949120000.0,],
+    199680000.0: [3194880000.0,],
+    200000000.0: [3200000000.0,],
+    204800000.0: [3072000000.0,2457600000.0],
+    240000000.0: [3000000000.0,],
+    245760000.0: [3194880000.0,3072000000.0,2949120000.0,2457600000.0],
+    250000000.0: [3000000000.0,2500000000.0],
+    256000000.0: [3200000000.0,3200000000.0],
+    266240000.0: [3194880000.0,],
+    300000000.0: [3000000000.0,],
+    307200000.0: [2457600000.0,],
+    320000000.0: [3200000000.0,],
+    327680000.0: [2949120000.0,2457600000.0],
+    360000000.0: [3000000000.0,],
+    368640000.0: [2949120000.0,],
+    375000000.0: [3000000000.0,],
+    384000000.0: [3072000000.0,],
+    399360000.0: [3194880000.0,],
+    400000000.0: [3200000000.0,],
+    409600000.0: [3072000000.0,2457600000.0],
+    450000000.0: [3000000000.0,],
+    460800000.0: [3072000000.0,2457600000.0],
+    480000000.0: [3000000000.0,3000000000.0],
+    491520000.0: [3194880000.0,3072000000.0,2949120000.0,2457600000.0],
+    500000000.0: [3000000000.0,2500000000.0],
+    512000000.0: [3072000000.0,3200000000.0],
+    532480000.0: [3194880000.0,],
+    552960000.0: [2949120000.0,],
+    599040000.0: [3194880000.0,],
+    600000000.0: [3000000000.0,3000000000.0],
+    614400000.0: [2457600000.0,],
+    625000000.0: [2500000000.0,],
+    640000000.0: [3200000000.0,3072000000.0],
+    655360000.0: [2949120000.0,2457600000.0],
+    665600000.0: [3194880000.0,],
+    720000000.0: [3000000000.0,],
+    737280000.0: [2949120000.0,],
+    750000000.0: [3000000000.0,],
+    768000000.0: [3072000000.0,],
+    798720000.0: [3194880000.0,],
+    800000000.0: [3200000000.0,],
+    819200000.0: [3072000000.0,2949120000.0,2457600000.0],
+    840000000.0: [3000000000.0,],
+    860160000.0: [3194880000.0,3072000000.0,2949120000.0,2457600000.0],
+    875000000.0: [3000000000.0,2500000000.0],
+    896000000.0: [3200000000.0,3072000000.0],
+    900000000.0: [3000000000.0,],
+    921600000.0: [3072000000.0,2949120000.0,2457600000.0],
+    931840000.0: [3194880000.0,],
+    960000000.0: [3000000000.0,3200000000.0],
+    983040000.0: [3194880000.0,3072000000.0,2949120000.0,2457600000.0],
+    998400000.0: [3194880000.0,],
+    1000000000.0: [3000000000.0,3200000000.0,2500000000.0],
+    1024000000.0: [3200000000.0,3072000000.0,2457600000.0],
+    1050000000.0: [3000000000.0,],
+    1064960000.0: [3194880000.0,],
+    1075200000.0: [3072000000.0,2457600000.0],
+    1080000000.0: [3000000000.0,],
+    1105920000.0: [2949120000.0,3194880000.0,3072000000.0,2457600000.0],
+    1120000000.0: [3200000000.0,],
+    1125000000.0: [3000000000.0,2500000000.0],
+    1146880000.0: [2949120000.0,2457600000.0],
+    1152000000.0: [3072000000.0,3200000000.0],
+    1198080000.0: [3194880000.0,],
+    1200000000.0: [3200000000.0,3000000000.0],
+    1228800000.0: [2457600000.0,],
+    1280000000.0: [3200000000.0,3072000000.0],
+    1290240000.0: [2949120000.0,],
+    1310720000.0: [2949120000.0,2457600000.0],
+    1331200000.0: [3194880000.0,],
+    1350000000.0: [3000000000.0,],
+    1382400000.0: [3072000000.0,2457600000.0],
+    1397760000.0: [3194880000.0,],
+    1400000000.0: [3200000000.0,3000000000.0],
+    1433600000.0: [3072000000.0,2457600000.0],
+    1440000000.0: [3000000000.0,3200000000.0],
+    1474560000.0: [2949120000.0,],
+    1500000000.0: [3000000000.0,],
+    1536000000.0: [3072000000.0,],
+    1600000000.0: [3200000000.0,],
+    1625000000.0: [3000000000.0,2500000000.0],
+    1638400000.0: [3072000000.0,2949120000.0,2457600000.0],
+    1650000000.0: [3000000000.0,],
+    1658880000.0: [2949120000.0,],
+    1664000000.0: [3200000000.0,3072000000.0],
+    1680000000.0: [3000000000.0,],
+    1689600000.0: [3072000000.0,2457600000.0],
+    1720320000.0: [3194880000.0,3072000000.0,2949120000.0,2457600000.0],
+    1730560000.0: [3194880000.0,],
+    1750000000.0: [3000000000.0,2500000000.0],
+    1760000000.0: [3200000000.0,],
+    1792000000.0: [3200000000.0,3072000000.0],
+    1797120000.0: [3194880000.0,],
+    1800000000.0: [3000000000.0,3200000000.0],
+    1802240000.0: [2949120000.0,2457600000.0],
+    1843200000.0: [2949120000.0,3194880000.0,3072000000.0,2457600000.0],
+    1863680000.0: [3194880000.0,],
+    1875000000.0: [3000000000.0,2500000000.0],
+    1920000000.0: [3000000000.0,3200000000.0,3072000000.0],
+    1950000000.0: [3000000000.0,],
+    1966080000.0: [3194880000.0,3072000000.0,2949120000.0,2457600000.0],
+    1996800000.0: [3194880000.0,3072000000.0,2457600000.0],
+    2000000000.0: [3000000000.0,3200000000.0,2500000000.0],
+    2027520000.0: [2949120000.0,],
+    2048000000.0: [3200000000.0,3072000000.0,2457600000.0]
  }
 
 MMCM_LOCKGROUP_LOOKUP = ( \
